Struct WpColorRepresentationSurfaceV1
pub struct WpColorRepresentationSurfaceV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
color representation extension to a surface
A wp_color_representation_surface_v1 allows the client to set the color representation metadata of a surface.
By default, a surface does not have any color representation metadata set. The reconstruction of R, G, B signals on such surfaces is compositor implementation defined. The alpha mode is assumed to be premultiplied_electrical when the alpha mode is unset.
If the wl_surface associated with the wp_color_representation_surface_v1 is destroyed, the wp_color_representation_surface_v1 object becomes inert.
See also the Request enum for this interface.